pm4py.statistics.passed\_time.log.variants package
==================================================

Submodules
----------

pm4py.statistics.passed\_time.log.variants.post module
------------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.log.variants.post
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.statistics.passed\_time.log.variants.pre module
-----------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.log.variants.pre
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.statistics.passed\_time.log.variants.prepost module
---------------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.log.variants.prepost
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.passed_time.log.variants
   :members:
   :undoc-members:
   :show-inheritance:
